==> gamgi_0.13.8+dfsg.orig.tar.gz: gamgi_0.13.8+dfsg/src/gtk/cell/gamgi_gtk_cell_link.h <==
/*********************************************
 *
 * $GAMGI/src/gtk/cell/gamgi_gtk_cell_link.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static gamgi_enum static_class (gamgi_window *window);

static void static_number (GtkWidget *widget, void *data);

static void static_wyckoff_change (GtkWidget *widget, void *data);

static void static_wyckoff_start (gamgi_window *window, gamgi_cell *cell);

static void static_nodes_start (gamgi_window *window, gamgi_cell *cell);

static void static_start_position (gamgi_window *window);

static void static_start_occupancy (gamgi_window *window);

static void static_start_packing (gamgi_window *window);

static void static_cell (GtkWidget *widget, void *data);

static void static_link (GtkWidget *widget, void *data);

static void static_hierarchy (GtkWidget *widget, void *data);

static void static_reset (gamgi_window *window);

static void static_clean (gamgi_cell *cell, gamgi_window *window);

static void static_global (GtkWidget *widget, void *data);

static void static_object (gamgi_cell *cell, 
gamgi_object *object, gamgi_window *window);

static void static_crystallographic (gamgi_cell *cell, 
gamgi_object *object, gamgi_window *window);

static void static_random (gamgi_cell *cell, 
gamgi_object *object, gamgi_window *window);

static void static_ok (GtkWidget *widget, void *data);

static void static_init (gamgi_window *window);

static void static_press (gamgi_object *object, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_cell_link_press (gamgi_window *window_mouse,
int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_cell_link (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Under development.

 *************
 * Rationale *
 *************/

==> gamgi_0.14.5.orig.tar.gz: gamgi0.14.5/src/gtk/cell/gamgi_gtk_cell_link.h <==
/*********************************************
 *
 * $GAMGI/src/gtk/cell/gamgi_gtk_cell_link.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static gamgi_enum static_class (gamgi_window *window);

static void static_number (GtkWidget *widget, void *data);

static void static_wyckoff_change (GtkWidget *widget, void *data);

static void static_wyckoff_start (gamgi_window *window, gamgi_cell *cell);

static void static_nodes_start (gamgi_window *window, gamgi_cell *cell);

static void static_start_position (gamgi_window *window);

static void static_start_occupancy (gamgi_window *window);

static void static_start_packing (gamgi_window *window);

static void static_cell (GtkWidget *widget, void *data);

static void static_method (GtkWidget *widget, void *data);

static void static_hierarchy (GtkWidget *widget, void *data);

static void static_reset (gamgi_window *window);

static void static_clean (gamgi_cell *cell, gamgi_window *window);

static void static_global (GtkWidget *widget, void *data);

static void static_object (gamgi_cell *cell, 
gamgi_object *object, gamgi_window *window);

static void static_crystallographic (gamgi_cell *cell, 
gamgi_object *object, gamgi_window *window);

static void static_random (gamgi_cell *cell, 
gamgi_object *object, gamgi_window *window);

static void static_ok (GtkWidget *widget, void *data);

static void static_init (gamgi_window *window);

static void static_press (gamgi_object *object, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_cell_link_press (gamgi_window *window_mouse,
GdkEventButton *event, int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_cell_link (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Under development.

 *************
 * Rationale *
 *************/
